==> Moony-0.9.0.tgz: Moony-0.9.0/Moony/Utils.php <==
<?php
/**
 * Moony - a simple web application framework
 *
 * @package Moony
 * @author YAMAOKA Hiroyuki <yamaoka@catwalker.jp>
 * @copyright 2005-2006 YAMAOKA Hiroyuki
 * @license http://www.opensource.org/licenses/bsd-license.php BSD License
 */

/**
 * ユーティリティを提供するクラスです。
 * 
 * @package Moony
 * @author YAMAOKA Hiroyuki <yamaoka@catwalker.jp>
 * @copyright 2005-2006 YAMAOKA Hiroyuki
 * @license http://www.opensource.org/licenses/bsd-license.php BSD License
 * @access public
 */
class Moony_Utils
{
    /**
     * 指定された変数をhtmlに埋め込むための
     * エスケープ処理を行います。
     *
     * @access public
     * @static
     * @param mixed $src エスケープ対象の変数
     * @return mixed エスケープ済みの変数
     */
    function escape($src)
    {
        if (is_array($src)) {
            return array_map(array('Moony_Utils', 'escape'), $src);
        }
        return htmlspecialchars($src, ENT_QUOTES);
    }

    /**
     * NULLバイト文字列を除去します。
     *
     * @access public
     * @static
     * @param mixed $src 処理対象の変数
     * @return mixed NULLバイトを除去した変数
     */
    function removeNullString($src)
    {
        if (is_array($src)) {
            return array_map(array('Moony_Utils', 'removeNullString'), $src);
        }
        return str_replace("\0", '', $src);
    }

    /**
     * パスを組み立てます。
     *
     * @access public
     * @static
     * @param string $dir ディレクトリ名
     * @param string $file ファイル名
     * @param string $ext ファイルの拡張子
     * @return string それぞれを連結したパス文字列
     */
    function buildPath($dir, $file, $ext = null)
    {
        if (strlen($dir) > 0 && substr($dir, -1, 1) == DIRECTORY_SEPARATOR) {
            $dir = substr($dir, 0, -1);
        }
        if (strlen($file) > 0 && substr($file, 0, 1) == DIRECTORY_SEPARATOR) {
            $file = substr($file, 1);
        }
        if (strlen($dir) > 0) {
            $file = $dir . DIRECTORY_SEPARATOR . $file;
        }
        if (strlen($ext) == 0 || strlen($file) == 0 || substr($file, -1, 1) == DIRECTORY_SEPARATOR) {
            return $file;
        }
        return $file . '.' . $ext;
    }

    /**
     * 指定されたURLにリダイレクトします。
     *
     * @access public
     * @static
     * @param string $url リダイレクト先のURL
     */
    function redirect($url)
    {
        if (!headers_sent()) {
            if (ob_get_length() !== false) {
                ob_end_clean();
            }
            header("Location: ${url}");
        }
    }

    /**
     * 指定されたステータス番号に対応した
     * HTTPのヘッダ情報を送出します。
     *
     * @access public
     * @static
     * @param integer $number 送出するhttpのステータス番号
     */
    function sendStatus($number)
    {
        static $status = array(
            100 => 'HTTP/1.0 100 Continue',
            101 => 'HTTP/1.0 101 Switching Protocols',
            200 => 'HTTP/1.0 200 OK',
            201 => 'HTTP/1.0 201 Created',
            202 => 'HTTP/1.0 202 Accepted',
            203 => 'HTTP/1.0 203 Non-Authoritative Information',
            204 => 'HTTP/1.0 204 No Content',
            205 => 'HTTP/1.0 205 Reset Content',
            206 => 'HTTP/1.0 206 Partial Content',
            300 => 'HTTP/1.0 300 Multiple Choices',
            301 => 'HTTP/1.0 301 Moved Permanently',
            302 => 'HTTP/1.0 302 Found',
            303 => 'HTTP/1.0 303 See Other',
            304 => 'HTTP/1.0 304 Not Modified',
            305 => 'HTTP/1.0 305 Use Proxy',
            307 => 'HTTP/1.0 307 Temporary Redirect',
            400 => 'HTTP/1.0 400 Bad Request',
            401 => 'HTTP/1.0 401 Unauthorized',
            402 => 'HTTP/1.0 402 Payment Required',
            403 => 'HTTP/1.0 403 Forbidden',
            404 => 'HTTP/1.0 404 Not Found',
            405 => 'HTTP/1.0 405 Method Not Allowed',
            406 => 'HTTP/1.0 406 Not Acceptable',
            407 => 'HTTP/1.0 407 Proxy Authentication Required',
            408 => 'HTTP/1.0 408 Request Time-out',
            409 => 'HTTP/1.0 409 Conflict',
            410 => 'HTTP/1.0 410 Gone',
            411 => 'HTTP/1.0 411 Length Required',
            412 => 'HTTP/1.0 412 Precondition Failed',
            413 => 'HTTP/1.0 413 Request Entity Too Large',
            414 => 'HTTP/1.0 414 Request-URI Too Large',
            415 => 'HTTP/1.0 415 Unsupported Media Type',
            416 => 'HTTP/1.0 416 Requested range not satisfiable',
            417 => 'HTTP/1.0 417 Expectation Failed',
            500 => 'HTTP/1.0 500 Internal Server Error',
            501 => 'HTTP/1.0 501 Not Implemented',
            502 => 'HTTP/1.0 502 Bad Gateway',
            503 => 'HTTP/1.0 503 Service Unavailable',
            504 => 'HTTP/1.0 504 Gateway Time-out'
        );
        if (isset($status[$number])) {
            header($status[$number]);
        }
    }

    /**
     * パスからファイル拡張子を取り除いた文字列を返します。
     * パスがDIRECTORY_SEPARATORで終了している場合、何も処理を行いません。
     *
     * @access public
     * @static
     * @param string $path 処理対象のパス
     * @return string 拡張子を取り除いた文字列
     */
    function removeFileExtension($path)
    {
        if (strlen($path) == 0 || substr($path, -1, 1) == DIRECTORY_SEPARATOR) {
            return $path;
        }
        $pos = strrpos($path, '.');
        if ($pos !== false) {
            $path = substr($path, 0, $pos);
        }
        return $path;
    }

    /**
     * 文字列が全て全角のカタカナで構成されているかどうか調べます。
     * 長音も全角のカタカナに含めます。長さ0の文字列の場合、無条件にtrueを返します。
     *
     * @access public
     * @static
     * @param string $str 検査対象の文字列
     * @return boolean 全てカタカナで構成されている場合true、そうでない場合false
     */
    function isKatakana($str)
    {
        if (MOONY_INTERNAL_ENCODING != 'EUC-JP') {
            $str = mb_convert_encoding($str, 'EUC-JP', MOONY_INTERNAL_ENCODING);
        }
        if (preg_match('/^(\xA5[\xA1-\xF6]|\xA1[\xBC])*$/', $str)) {
            return true;
        }
        return false;
    }

    /**
     * 半角文字を1、全角文字を2とした場合の文字列の幅を返します。
     * 戻り値は内部エンコーディングに依存しません。
     *
     * @access public
     * @static
     * @param string $str 処理対象の文字列
     * @return integer 半角文字を1、全角文字を2とした場合の文字列の幅
     */
    function getStrWidth($str)
    {
        if (MOONY_INTERNAL_ENCODING != 'EUC-JP') {
            $str = mb_convert_encoding($str, 'EUC-JP', MOONY_INTERNAL_ENCODING);
        }
        $b = unpack('C*', $str);
        return count($b);
    }

    /**
     * 配列でないスカラー値を要素が1つの配列に変換します。
     *
     * @access public
     * @static
     * @param mixed $var 配列として扱う値
     * @return array 配列に変換された値
     */
    function toArray($var) {
        if (is_array($var)) {
            return $var;
        }
        return array($var);
    }

    /**
     * 配列の要素の値を取得します。
     * 該当するキーが存在しない場合、指定された代替値を返します。
     *
     * @access public
     * @static
     * @param integer|string $key 配列のキー
     * @param array $array 処理対象の配列
     * @param mixed $alt 代替値
     * @return 該当する要素の値、または代替値
     */
    function getArrayValue($key, $array, $alt = null)
    {
        if (is_array($array) && isset($array[$key])) {
            return $array[$key];
        }
        return $alt;
    }

    /**
     * CamelCaseに変換します。
     * 例えば、regist_userをRegistUserに変換します。
     *
     * @access public
     * @static
     * @param string $str 変換対象文字列
     * @param string $delim 変換元の単語区切り文字
     * @return string CamelCaseに変換した文字列
     */
    function camelCase($str, $delim = '_')
    {
        if (strlen($delim) == 0) {
            return ucwords($str);
        }
        $words = explode($delim, $str);
        for ($i = 0; $i < count($words); $i++) {
            $words[$i] = ucfirst($words[$i]);
        }
        return implode('', $words);
    }
}
?>

==> Moony-0.10.0.tgz: Moony-0.10.0/Moony/Utils.php <==
<?php
/**
 * Moony - a simple web application framework
 *
 * @package Moony
 * @author YAMAOKA Hiroyuki <yamaoka@catwalker.jp>
 * @copyright 2005-2006 YAMAOKA Hiroyuki
 * @license http://www.opensource.org/licenses/bsd-license.php BSD License
 */

/**
 * ユーティリティを提供するクラスです。
 * 
 * @package Moony
 * @author YAMAOKA Hiroyuki <yamaoka@catwalker.jp>
 * @copyright 2005-2006 YAMAOKA Hiroyuki
 * @license http://www.opensource.org/licenses/bsd-license.php BSD License
 * @access public
 */
class Moony_Utils
{
    /**
     * パスを組み立てます。
     *
     * @access public
     * @static
     * @param string $dir ディレクトリ名
     * @param string $file ファイル名
     * @param string $ext ファイルの拡張子
     * @return string それぞれを連結したパス文字列
     */
    function buildPath($dir, $file, $ext = null)
    {
        if (strlen($dir) > 0 && substr($dir, -1, 1) == DIRECTORY_SEPARATOR) {
            $dir = substr($dir, 0, -1);
        }
        if (strlen($file) > 0 && substr($file, 0, 1) == DIRECTORY_SEPARATOR) {
            $file = substr($file, 1);
        }
        if (strlen($dir) > 0) {
            $file = $dir . DIRECTORY_SEPARATOR . $file;
        }
        if (strlen($ext) == 0 || strlen($file) == 0 || substr($file, -1, 1) == DIRECTORY_SEPARATOR) {
            return $file;
        }
        return $file . '.' . $ext;
    }

    /**
     * パスからファイル拡張子を取り除いた文字列を返します。
     * パスがDIRECTORY_SEPARATORで終了している場合、何も処理を行いません。
     *
     * @access public
     * @static
     * @param string $path 処理対象のパス
     * @return string 拡張子を取り除いた文字列
     */
    function removeFileExtension($path)
    {
        if (strlen($path) == 0 || substr($path, -1, 1) == DIRECTORY_SEPARATOR) {
            return $path;
        }
        $pos = strrpos($path, '.');
        if ($pos !== false) {
            $path = substr($path, 0, $pos);
        }
        return $path;
    }

    /**
     * 配列でないスカラー値を要素が1つの配列に変換します。
     *
     * @access public
     * @static
     * @param mixed $var 配列として扱う値
     * @return array 配列に変換された値
     */
    function toArray($var) {
        return is_array($var) ? $var : array($var);
    }

    /**
     * 配列の要素の値を取得します。
     * 該当するキーが存在しない場合、指定された代替値を返します。
     *
     * @access public
     * @static
     * @param integer|string $key 配列のキー
     * @param array $array 処理対象の配列
     * @param mixed $alt 代替値
     * @return 該当する要素の値、または代替値
     */
    function getArrayValue($key, $array, $alt = null)
    {
        if (is_array($array) && array_key_exists($key, $array)) {
            return $array[$key];
        }
        return $alt;
    }

    /**
     * CamelCaseに変換します。
     * 例えば、regist_userをRegistUserに変換します。
     *
     * @access public
     * @static
     * @param string $str 変換対象文字列
     * @param string $delim 変換元の単語区切り文字
     * @return string CamelCaseに変換した文字列
     */
    function camelize($str, $delim = '_')
    {
        if (strlen($delim) == 0) {
            return ucwords($str);
        }
        $words = explode($delim, $str);
        for ($i = 0; $i < count($words); $i++) {
            $words[$i] = ucfirst($words[$i]);
        }
        return implode('', $words);
    }

    /**
     * NUL文字を除去します。
     *
     * @access private
     * @param mixed $var 処理対象の変数
     * @return mixed NUL文字を除去した変数
     */
    function removeNulString($var)
    {
        if (is_array($var)) {
            return array_map(array('Moony_Utils', 'removeNulString'), $var);
        }
        return str_replace("\0", '', $var);
    }

    /**
     * PATH_INOを取得します。
     * 取得できない場合、無条件に長さ0の文字列を返します。
     *
     * @access public
     * @static
     * @return string PATH_INFO
     */
    function getPathInfo()
    {
        $path_info = Moony_Utils::getArrayValue('PATH_INFO', $_SERVER, '');
        return Moony_Utils::removeNulString($path_info);
    }

    /**
     * 指定されたファイルが読み込み可能かどうかを調べます。
     * include_pathを考慮して調べます。
     *
     * @access public
     * @static
     * @param string $file_name ファイル名称
     * @return boolean 読み込み可能ならtrue
     */
    function isReadableFile($file_name)
    {
        $fp = @fopen($file_name, 'r', true);
        if (is_resource($fp)) {
            fclose($fp);
            return true;
        }
        return false;
    }

    /**
     * 指定されたディレクトリが書き込み可能かどうか調べます。
     * ディレクトリが存在しない場合、パーミッション0777で作成を試みます。
     * 書き込み権限がない場合、パーミッションを0777に変更を試みます。
     * 最終的に書き込み可能な状態になった場合だけ、trueを返します。
     * それ以外の場合はすべてfalseを返します。
     *
     * @access public
     * @static
     * @param string $dir_name ディレクトリ名
     * @return boolean 書き込み可能ならtrue
     */
    function isWritableDir($dir_name)
    {
        if (!file_exists($dir_name)) {
            if (!mkdir($dir_name, 0777)) {
                return false;
            }
        }
        if (!is_writable($dir_name)) {
            if (!chmod($dir_name, 0777)) {
                return false;
            }
        }
        return true;
    }
}
?>
